[PATCH] don't include s390 packages when composing s390x image

Dan Horák dan at danny.cz
Wed Aug 3 08:15:32 UTC 2011


---
 src/pypungi/__init__.py |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/pypungi/__init__.py b/src/pypungi/__init__.py
index 72759a3..4769427 100644
--- a/src/pypungi/__init__.py
+++ b/src/pypungi/__init__.py
@@ -238,9 +238,9 @@ class Pungi(pypungi.PungiBase):
 
         self.ayum.compatarch = yumarch
         # Filter out all the multilib arches, anaconda won't use them.
         # only makes sense on x86_64 
         full_archlist = set(yum.rpmUtils.arch.getArchList(yumarch))
-        if arch == 'x86_64':
+        if arch in ['x86_64', 's390x']:
             compat_archinfo = yum.rpmUtils.arch.getMultiArchInfo(yumarch)
             compat_archlist = set(yum.rpmUtils.arch.getArchList(compat_archinfo[0]))
             newarchlist = list(full_archlist.difference(compat_archlist))
@@ -238,9 +238,9 @@ class Pungi(pypungi.PungiBase):
         self.ayum.compatarch = yumarch
         # Filter out all the multilib arches, anaconda won't use them.
-        # only makes sense on x86_64 
+        # only makes sense on x86_64 and s390x
         full_archlist = set(yum.rpmUtils.arch.getArchList(yumarch))
-- 
1.7.4.4



More information about the buildsys mailing list